# spreg

[![Build Status](https://travis-ci.com/pysal/spreg.svg?branch=master)](https://travis-ci.com/pysal/spreg)
[![Coverage Status](https://coveralls.io/repos/github/pysal/spreg/badge.svg?branch=master)](https://coveralls.io/github/pysal/spreg?branch=master&service=github)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/spreg)
![PyPI](https://img.shields.io/pypi/v/spreg)
![Conda (channel only)](https://img.shields.io/conda/vn/conda-forge/spreg)
![GitHub commits since latest release (branch)](https://img.shields.io/github/commits-since/pysal/spreg/latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3973200.svg)](https://doi.org/10.5281/zenodo.3973200)

## PySAL Spatial Econometrics Package

`spreg`, short for “spatial regression,” is a Python package to estimate simultaneous autoregressive spatial regression models. These models are useful when modeling processes where observations interact with one another. 
This package is part of a [refactoring of PySAL](https://github.com/pysal/pysal/wiki/PEP-13:-Refactor-PySAL-Using-Submodules)

## License information

See the file "LICENSE.txt" for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.

